..
  This file is part of cds_dojson
  Copyright (C) 2015 CERN.

  cds_dojson is free software; you can redistribute it and/or
  modify it under the terms of the Revised BSD License; see LICENSE
  file for more details.

===========
 cds_dojson
===========
.. currentmodule:: cds_dojson

.. raw:: html

    <p style="height:22px; margin:0 0 0 2em; float:right">
        <a href="https://travis-ci.org/CERNDocumentServer/cds-dojson">
            <img src="https://travis-ci.org/CERNDocumentServer/cds-dojson.png?branch=master"
                 alt="travis-ci badge"/>
        </a>
        <a href="https://coveralls.io/r/CERNDocumentServer/cds-dojson">
            <img src="https://coveralls.io/repos/CERNDocumentServer/cds-dojson/badge.png?branch=master"
                 alt="coveralls.io badge"/>
        </a>
    </p>

cds_dojson is a simple Pythonic JSON to JSON converter.

Installation
============

cds_dojson is on PyPI so all you need is:

.. code-block:: console

    $ pip install cds-dojson


API
===

.. automodule:: cds_dojson
    :members:


Contrib
-------

.. automodule:: cds_dojson.marc21
    :members:

.. include:: ../CHANGES.rst

.. include:: ../CONTRIBUTING.rst

.. include:: ../AUTHORS.rst

License
=======

.. include:: ../LICENSE
